sequencetools.retain_sequence_elements_at_indices
=================================================

.. autofunction:: abjad.tools.sequencetools.retain_sequence_elements_at_indices.retain_sequence_elements_at_indices
   :noindex:
